# AirobotLibrary

Airtest Project的Airtest-Selenium插件功能扩展，整合了RobotFramework框架SeleniumLibrary的方法以及部分扩展库。

集成以下扩展库

    robotframework-seleniumlibrary
    robotframework-appiumlibrary
    robotframework-requests 
    robotframework-databaselibrary
    robotframework-ftplibrary 
    robotframework-archivelibrary 
    robotframework-difflibrary 

请自行在 `https://npm.taobao.org/mirrors/chromedriver` 下载跟Chrome浏览器版本对应的驱动，放在系统PATH中。